seaquell.core

seaquell.mapify

Contains functions for transforming vector values into map values and map values into vector values. These functions are useful when you need to transform between an associative structure with arbitrary ordering to one with ordering.

Contains functions for transforming vector values into map values and
map values into vector values. These functions are useful when you need to
transform between an associative structure with arbitrary ordering to one
with ordering.
raw docstring

seaquell.raw

Experimental namespace for representing SQL using sequential data structures instead of maps. Would let users generate arbitrary SQL. Similar to hiccup for HTML.

Experimental namespace for representing SQL using sequential data
structures instead of maps. Would let users generate arbitrary
SQL. Similar to hiccup for HTML.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries